/**
 * @param {?} ua
 * @return {?}
 */
export function isBrowserSupport(ua) {
    if (!!window['chrome'] && !!window['chrome']['webstore']) {
        return true;
    }
    else if (ua.indexOf('Firefox') !== -1) {
        var /** @type {?} */ match = /((?!Gecko.+)Firefox|Gecko(?!.+Firefox))(?: |\/)([\d]+)/.exec(ua);
        var /** @type {?} */ ver = +match[2];
        return !!match[1] && !isNaN(ver) && ver >= 27; // Firefox 27+
    }
    else if (ua.indexOf('Safari') !== -1) {
        var /** @type {?} */ match = /(?:iPod|iPhone|iPad).+Version\/(\d+\.\d+).*Safari/.exec(ua); // iOS safari 7.1+
        var /** @type {?} */ ver = match ? +match[1] : 0;
        if (!isNaN(ver)) {
            return ver >= 7.1;
        }
        match = /Version\/(\d+)\.\d+(?:\.\d+)?.*Safari/.exec(ua); // OS X Safari 9+
        ver = match ? +match[1] : 0;
        if (!isNaN(ver)) {
            return ver >= 9;
        }
    }
    else if (ua.indexOf('MSIE') !== -1) {
        return ua.indexOf('MSIE 10') !== -1; // filter out all IE but IE10
    }
    else if (ua.indexOf('Edge') || ua.indexOf('Trident')) {
        return true; // IE11 and Edge
    }
    return false;
}
//# sourceMappingURL=browser-detect.js.map